Screen {
    layout: vertical;
    align: center middle;
}

/* 下载进度条全屏展示 */
#download-button-container, #download-button {
    width: 100%;
    height: auto;
    layout: horizontal;
}


Container {
    width: 80%;
    height: 80%;
    border: round #666;
    padding: 1;
}

#form-container{
    width: 60%;
    height: auto;
}

#button-container {
    layout: horizontal;
    width: 100%;
    height: auto;
    margin-top: 1;
}


Button {
    width: 12;
    margin-left: 1;
}

DataTable {
    width: 100%;
    height: 80%;
}

#config-buttons, #file-buttons, #download-buttons {
    layout: horizontal;
    height: auto;
    margin-top: 1;
}

Input {
    margin: 1 0;
}


Center {
    margin-top: 1;
    margin-bottom: 1;
    layout: horizontal;
}

ProgressBar {
    padding-left: 1;
}

Input {
    width: 100%;
}

VerticalScroll {
    height: auto;
}